@@ -2,17 +2,20 @@
 # tcplSendQuery: Send query to the tcpl databases
 #-------------------------------------------------------------------------------
 
+#' @param tbl Tables to be read queried
+#' @param delete Logical of length 1, execute delete on queried table
+#'
 #' @rdname query_funcs
 #' 
 #' @import DBI
-#' @importFrom RSQLite SQLite 
 #' @import data.table
 #' @importFrom RMySQL MySQL
 #' @importFrom methods is
+#' @importFrom sqldf sqldf
 #' @export
 
 tcplSendQuery <- function(query, db = getOption("TCPL_DB"), 
-                          drvr = getOption("TCPL_DRVR")) {
+                          drvr = getOption("TCPL_DRVR"), tbl=NULL, delete=F) {
   
   #Check for valid inputs
   if (length(query) != 1 | class(query) != "character") {
@@ -24,12 +27,6 @@ tcplSendQuery <- function(query, db = getOption("TCPL_DB"),
   
   db_pars <- NULL
   
-  if (getOption("TCPL_DRVR") == "SQLite") {
-    
-    db_pars <- list(drv = SQLite(),
-                    dbname = db)
-    
-  }
   
   if (getOption("TCPL_DRVR") == "MySQL") {
     
@@ -46,6 +43,28 @@ tcplSendQuery <- function(query, db = getOption("TCPL_DB"),
     
   }
   
+  if (getOption("TCPL_DRVR") == "tcplLite") {
+    db_pars <- "Just running tcplLite, we're OK"
+    
+    for (t in tbl) {
+      fpath <- paste(db, t, sep='/')
+      fpath <- paste(fpath, 'csv', sep='.')
+      assign(t, read.table(fpath, header=T, sep=','))
+    }
+
+    temp <- as.data.table(sqldf(query, stringsAsFactors=F))
+    
+    if (delete == T) {
+      if (length(tbl) > 1) {
+        stop("Can't execute delete on more that one table")
+      }
+      db_pars <- db
+      fpath <- paste(db, tbl, sep='/')
+      fpath <- paste(fpath, 'csv', sep='.')
+      write.table(temp, file=fpath, append=F, row.names=F, sep=',', col.names=T) # Need to rewrite whole table
+    }
+  }
+  
   if (is.null(db_pars)) {
     
     stop(getOption("TCPL_DRVR"), " is not a supported database system. See ",
@@ -53,10 +72,12 @@ tcplSendQuery <- function(query, db = getOption("TCPL_DB"),
     
   }
   
-  dbcon <- do.call(dbConnect, db_pars)
-  temp <- try(dbSendQuery(dbcon, query), silent = TRUE)
-  if (!is(temp, "try-error")) dbClearResult(temp)
-  dbDisconnect(dbcon)
+  if (drvr == 'MySQL') {
+    dbcon <- do.call(dbConnect, db_pars)
+    temp <- try(dbSendQuery(dbcon, query), silent = TRUE)
+    if (!is(temp, "try-error")) dbClearResult(temp)
+    dbDisconnect(dbcon)
+  }
   
   if (!is(temp, "try-error")) return(TRUE)
   
